==> qtjambi-help-debuginfo-linux-x64-6.5.3.jar: sources/QtJambiHelp/QCompressedHelpInfo_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtHelp/qcompressedhelpinfo.h>
#include <QtCore/QVariant>
#include <QtCore/qversionnumber.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QCompressedHelpInfo(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QCompressedHelpInfo")
    QCompressedHelpInfo *_ptr = reinterpret_cast<QCompressedHelpInfo *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QCompressedHelpInfo()
void __qt_construct_QCompressedHelpInfo_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QCompressedHelpInfo()")
    Q_UNUSED(__java_arguments)
    QCompressedHelpInfo *__qt_this = new(__qtjambi_ptr) QCompressedHelpInfo();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QCompressedHelpInfo(QCompressedHelpInfo)
void __qt_construct_QCompressedHelpInfo_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QCompressedHelpInfo(QCompressedHelpInfo)")
    jobject other0 = __java_arguments[0].l;
    const QCompressedHelpInfo& __qt_other0 = qtjambi_cast<const QCompressedHelpInfo& >(__jni_env, other0);
    QCompressedHelpInfo *__qt_this = new(__qtjambi_ptr) QCompressedHelpInfo(__qt_other0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QCompressedHelpInfo
void __qt_destruct_QCompressedHelpInfo(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QCompressedHelpInfo")
    reinterpret_cast<QCompressedHelpInfo*>(ptr)->~QCompressedHelpInfo();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QCompressedHelpInfo::QCompressedHelpInfo()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QCompressedHelpInfo_initialize_1native__Lio_qt_help_QCompressedHelpInfo_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCompressedHelpInfo::QCompressedHelpInfo()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QCompressedHelpInfo_0, sizeof(QCompressedHelpInfo), typeid(QCompressedHelpInfo), false, &deleter_QCompressedHelpInfo, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QCompressedHelpInfo::QCompressedHelpInfo(QCompressedHelpInfo)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QCompressedHelpInfo_initialize_1native__Lio_qt_help_QCompressedHelpInfo_2Lio_qt_help_QCompressedHelpInfo_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCompressedHelpInfo::QCompressedHelpInfo(QCompressedHelpInfo)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QCompressedHelpInfo_1, sizeof(QCompressedHelpInfo), typeid(QCompressedHelpInfo), false, &deleter_QCompressedHelpInfo, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QCompressedHelpInfo::component()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QCompressedHelpInfo_component_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QCompressedHelpInfo *__qt_this = QtJambiAPI::objectFromNativeId<QCompressedHelpInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCompressedHelpInfo::component()const", __qt_this)
        QString __qt_return_value = __qt_this->component();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QCompressedHelpInfo::isNull()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QCompressedHelpInfo_isNull_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QCompressedHelpInfo *__qt_this = QtJambiAPI::objectFromNativeId<QCompressedHelpInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCompressedHelpInfo::isNull()const", __qt_this)
        __java_return_value = __qt_this->isNull();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QCompressedHelpInfo::namespaceName()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QCompressedHelpInfo_namespaceName_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QCompressedHelpInfo *__qt_this = QtJambiAPI::objectFromNativeId<QCompressedHelpInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCompressedHelpInfo::namespaceName()const", __qt_this)
        QString __qt_return_value = __qt_this->namespaceName();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QCompressedHelpInfo::operator=(QCompressedHelpInfo)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QCompressedHelpInfo_assign_1native_1cref_1QCompressedHelpInfo__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QCompressedHelpInfo *__qt_this = QtJambiAPI::objectFromNativeId<QCompressedHelpInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCompressedHelpInfo::operator=(QCompressedHelpInfo)", __qt_this)
        const QCompressedHelpInfo& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QCompressedHelpInfo>(other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QCompressedHelpInfo::swap(QCompressedHelpInfo&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QCompressedHelpInfo_swap_1native_1ref_1QCompressedHelpInfo__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QCompressedHelpInfo *__qt_this = QtJambiAPI::objectFromNativeId<QCompressedHelpInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCompressedHelpInfo::swap(QCompressedHelpInfo&)", __qt_this)
        QCompressedHelpInfo& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QCompressedHelpInfo>(__jni_env, other0);
        __qt_this->swap(__qt_other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QCompressedHelpInfo::version()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QCompressedHelpInfo_version_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QCompressedHelpInfo *__qt_this = QtJambiAPI::objectFromNativeId<QCompressedHelpInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCompressedHelpInfo::version()const", __qt_this)
        QVersionNumber __qt_return_value = __qt_this->version();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QCompressedHelpInfo::fromCompressedHelpFile(QString)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QCompressedHelpInfo_fromCompressedHelpFile__Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jclass,
 jstring documentationFileName0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCompressedHelpInfo::fromCompressedHelpFile(QString)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QString  __qt_documentationFileName0 = qtjambi_cast<QString >(__jni_env, documentationFileName0);
        QCompressedHelpInfo __qt_return_value = QCompressedHelpInfo::fromCompressedHelpFile(__qt_documentationFileName0);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QCompressedHelpInfo_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QCompressedHelpInfo *__qt_this = QtJambiAPI::objectFromNativeId<QCompressedHelpInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QCompressedHelpInfo(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QCompressedHelpInfo>("QCompressedHelpInfo", "io/qt/help/QCompressedHelpInfo");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QCompressedHelpInfo, {
        ConstructorInfo(&__qt_construct_QCompressedHelpInfo_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QCompressedHelpInfo_1, "Lio/qt/help/QCompressedHelpInfo;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QCompressedHelpInfo);
    registerMetaType<QCompressedHelpInfo>("QCompressedHelpInfo");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-help-debuginfo-linux-x64-6.5.5.jar: sources/QtJambiHelp/QCompressedHelpInfo_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtHelp/qcompressedhelpinfo.h>
#include <QtCore/QVariant>
#include <QtCore/qversionnumber.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QCompressedHelpInfo(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QCompressedHelpInfo")
    QCompressedHelpInfo *_ptr = reinterpret_cast<QCompressedHelpInfo *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QCompressedHelpInfo()
void __qt_construct_QCompressedHelpInfo(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QCompressedHelpInfo()")
    Q_UNUSED(__java_arguments)
    QCompressedHelpInfo *__qt_this = new(__qtjambi_ptr) QCompressedHelpInfo();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QCompressedHelpInfo::QCompressedHelpInfo()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QCompressedHelpInfo_initialize_1native__Lio_qt_help_QCompressedHelpInfo_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCompressedHelpInfo::QCompressedHelpInfo()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QCompressedHelpInfo, sizeof(QCompressedHelpInfo), typeid(QCompressedHelpInfo), false, &deleter_QCompressedHelpInfo, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QCompressedHelpInfo(QCompressedHelpInfo)
void __qt_construct_QCompressedHelpInfo_cref_QCompressedHelpInfo(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QCompressedHelpInfo(QCompressedHelpInfo)")
    jobject other0 = __java_arguments[0].l;
    const QCompressedHelpInfo& __qt_other0 = qtjambi_cast<const QCompressedHelpInfo& >(__jni_env, other0);
    QCompressedHelpInfo *__qt_this = new(__qtjambi_ptr) QCompressedHelpInfo(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QCompressedHelpInfo::QCompressedHelpInfo(QCompressedHelpInfo)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QCompressedHelpInfo_initialize_1native__Lio_qt_help_QCompressedHelpInfo_2Lio_qt_help_QCompressedHelpInfo_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCompressedHelpInfo::QCompressedHelpInfo(QCompressedHelpInfo)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QCompressedHelpInfo_cref_QCompressedHelpInfo, sizeof(QCompressedHelpInfo), typeid(QCompressedHelpInfo), false, &deleter_QCompressedHelpInfo, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QCompressedHelpInfo
void __qt_destruct_QCompressedHelpInfo(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QCompressedHelpInfo")
    reinterpret_cast<QCompressedHelpInfo*>(ptr)->~QCompressedHelpInfo();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QCompressedHelpInfo::component()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QCompressedHelpInfo_component_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QCompressedHelpInfo *__qt_this = QtJambiAPI::objectFromNativeId<QCompressedHelpInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCompressedHelpInfo::component()const", __qt_this)
        QString __qt_return_value = __qt_this->component();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QCompressedHelpInfo::isNull()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QCompressedHelpInfo_isNull_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QCompressedHelpInfo *__qt_this = QtJambiAPI::objectFromNativeId<QCompressedHelpInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCompressedHelpInfo::isNull()const", __qt_this)
        __java_return_value = __qt_this->isNull();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QCompressedHelpInfo::namespaceName()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QCompressedHelpInfo_namespaceName_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QCompressedHelpInfo *__qt_this = QtJambiAPI::objectFromNativeId<QCompressedHelpInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCompressedHelpInfo::namespaceName()const", __qt_this)
        QString __qt_return_value = __qt_this->namespaceName();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QCompressedHelpInfo::operator=(QCompressedHelpInfo)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QCompressedHelpInfo_assign_1native_1cref_1QCompressedHelpInfo__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QCompressedHelpInfo *__qt_this = QtJambiAPI::objectFromNativeId<QCompressedHelpInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCompressedHelpInfo::operator=(QCompressedHelpInfo)", __qt_this)
        const QCompressedHelpInfo& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QCompressedHelpInfo>(other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QCompressedHelpInfo::swap(QCompressedHelpInfo&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QCompressedHelpInfo_swap_1native_1ref_1QCompressedHelpInfo__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QCompressedHelpInfo *__qt_this = QtJambiAPI::objectFromNativeId<QCompressedHelpInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCompressedHelpInfo::swap(QCompressedHelpInfo&)", __qt_this)
        QCompressedHelpInfo& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QCompressedHelpInfo>(__jni_env, other0);
        __qt_this->swap(__qt_other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QCompressedHelpInfo::version()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QCompressedHelpInfo_version_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QCompressedHelpInfo *__qt_this = QtJambiAPI::objectFromNativeId<QCompressedHelpInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCompressedHelpInfo::version()const", __qt_this)
        QVersionNumber __qt_return_value = __qt_this->version();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QCompressedHelpInfo::fromCompressedHelpFile(QString)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QCompressedHelpInfo_fromCompressedHelpFile__Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jclass,
 jstring documentationFileName0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCompressedHelpInfo::fromCompressedHelpFile(QString)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QString  __qt_documentationFileName0 = qtjambi_cast<QString>(__jni_env, documentationFileName0);
        QCompressedHelpInfo __qt_return_value = QCompressedHelpInfo::fromCompressedHelpFile(__qt_documentationFileName0);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QCompressedHelpInfo_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QCompressedHelpInfo *__qt_this = QtJambiAPI::objectFromNativeId<QCompressedHelpInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QCompressedHelpInfo(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QCompressedHelpInfo>("QCompressedHelpInfo", "io/qt/help/QCompressedHelpInfo");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QCompressedHelpInfo, {
        ConstructorInfo(&__qt_construct_QCompressedHelpInfo, nullptr)
       ,ConstructorInfo(&__qt_construct_QCompressedHelpInfo_cref_QCompressedHelpInfo, "Lio/qt/help/QCompressedHelpInfo;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QCompressedHelpInfo);
    registerMetaType<QCompressedHelpInfo>("QCompressedHelpInfo");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
